---
name: Bug report
about: Create a report to help us improve
labels: bug
---

### Describe the bug

### To Reproduce
Steps to reproduce the behavior:

### Expected behavior

### Screenshots / Logs

### Environment
- MEMG version:
- OS:
- Python version:

### Additional context
